#
# spec file for package hunspell
#
# Copyright (c) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Summary:        Hunspell - a spell checker and morphological analyzer library
License:        (GPL-2.0+ or LGPL-2.1+ or MPL-1.1+) and LGPL-2.1+
Group:          System/Libraries

Name:           hunspell
%define ver     1.3
Version:        %{ver}.2
Release:        6.6
Url:            http://hunspell.sourceforge.net/
Source0:        http://downloads.sourceforge.net/project/%{name}/Hunspell/%{version}/%{name}-%{version}.tar.gz
Source1:        baselibs.conf
BuildRequires:  autoconf >= 2.59
BuildRequires:  automake
BuildRequires:  gcc-c++
BuildRequires:  libstdc++-devel
BuildRequires:  libtool
BuildRequires:  ncurses-devel >= 5.0
BuildRequires:  pkg-config
BuildRequires:  readline-devel
Recommends:     %{name}-tools
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Hunspell is a spell checker and morphological analyzer library and
program designed for languages with rich morphology and complex word
compounding or character encoding. Hunspell interfaces: Ispell-like
terminal interface using Curses library, Ispell pipe interface,
LibreOffice or OpenOffice.org UNO module.

%package tools
Summary:        Hunspell tools
Group:          Development/Libraries/Other
Requires:       %{name} = %{version}

%description tools
This package contains munch and unmunch programs.

%package devel
Summary:        Files for developing with hunspell
Group:          Development/Libraries/Other
Requires:       %{name} = %{version}
Requires:       libstdc++-devel
Requires:       pkgconfig

%description devel
Includes and definitions for developing with hunspell.

%package static
Summary:        Static hunspell library
Group:          Development/Libraries/Other
Requires:       %{name}-devel = %{version}

%description static
Static hunspell library.

%prep
%setup -q

%build
%configure \
	--with-ui \
	--with-readline
make %{?_smp_mflags}

%install
%makeinstall
rm -f %{buildroot}%{_bindir}/example
install -m 644 src/tools/{,un}munch.h %{buildroot}%{_includedir}
ln -sf %{_libdir}/libhunspell-%{ver}.so.0.0.0 %{buildroot}%{_libdir}/libhunspell.so
%find_lang %{name}

%check
make check

%post	-p /sbin/ldconfig

%postun	-p /sbin/ldconfig

%files -f %{name}.lang
%defattr(644,root,root,755)
%doc README README.myspell AUTHORS AUTHORS.myspell COPYING THANKS license.hunspell license.myspell
%attr(755,root,root) %{_bindir}/hunspell
%attr(755,root,root) %{_libdir}/libhunspell*.so*
%exclude %{_libdir}/libhunspell*.so
%dir %{_mandir}/hu
%dir %{_mandir}/hu/man1
%dir %{_mandir}/hu/man4
%{_mandir}/man1/hunspell.1*
%{_mandir}/man4/hunspell.4*
%{_mandir}/man1/hunzip.1*
%{_mandir}/man1/hzip.1*
%{_mandir}/man3/hunspell.3*
%lang(hu) %{_mandir}/hu/man1/hunspell.1*
%lang(hu) %{_mandir}/hu/man4/hunspell.4*

%files tools
%defattr(644,root,root,755)
%attr(755,root,root) %{_bindir}/analyze
%attr(755,root,root) %{_bindir}/chmorph
%attr(755,root,root) %{_bindir}/munch
%attr(755,root,root) %{_bindir}/unmunch
%attr(755,root,root) %{_bindir}/hunzip
%attr(755,root,root) %{_bindir}/hzip
%attr(755,root,root) %{_bindir}/affixcompress
%attr(755,root,root) %{_bindir}/ispellaff2myspell
%attr(755,root,root) %{_bindir}/makealias
%attr(755,root,root) %{_bindir}/wordforms
%attr(755,root,root) %{_bindir}/wordlist2hunspell

%files devel
%defattr(644,root,root,755)
%attr(755,root,root) %{_libdir}/libhunspell*.so
%{_libdir}/libhunspell-*.la
%{_libdir}/libparsers.a
%{_includedir}/%{name}
%{_includedir}/munch.h
%{_includedir}/unmunch.h
#%{_pkgconfigdir}/hunspell.pc
%{_libdir}/pkgconfig/hunspell.pc

%files static
%defattr(644,root,root,755)
%{_libdir}/libhunspell-*.a

%changelog
* Thu May 12 2016 tchvatal@suse.com
- Update baselibs to provide hunspell-devel bnc#977784
* Thu Mar 28 2013 mmeister@suse.com
- Added url as source.
  Please see http://en.opensuse.org/SourceUrls
* Mon Sep  3 2012 pgajdos@suse.com
- added /usr/lib64/libhunspell.so on request from egdfree@opensuse.org
* Wed Dec 14 2011 cfarrell@suse.com
- license update: (GPL-2.0+ or LGPL-2.1+ or MPL-1.1+) and LGPL-2.1+
  SPDX syntax describing the COPYING file statesments
* Fri Dec  9 2011 jengelh@medozas.de
- Remove redundant/unwanted tags/section (cf. specfile guidelines)
* Fri Dec  9 2011 coolo@suse.com
- fix license to be in spdx.org format
* Mon Sep 26 2011 pgajdos@suse.com
- enhanced description [bnc#718111]
* Mon Mar 28 2011 pgajdos@suse.cz
- update to version 1.3.2:
  * fixes library version inconsistency [bnc#682768]
* Fri Mar 25 2011 idoenmez@novell.com
- Spec cleanup
- Removed hunspell-disable-fortify.patch: we want to build
  with fortify again now that the code is fixed.
* Fri Mar 11 2011 pgajdos@suse.cz
- updated to 1.3.1:
  - new branch
  - bug fixes
* Tue Mar  1 2011 dmueller@suse.de
- update to 1.2.15:
  - bug fixes
  - new options: -r to filter potential mistakes (rare words
    signed by flag WARN in the dictionary)
  - limited and optimized suggestions
* Mon Aug 30 2010 pgajdos@suse.cz
- update to 1.2.12:
  * Maintenance release bug fixes and warnings
- upstreamed fix-format.patch
* Sat Apr 24 2010 coolo@novell.com
- buildrequire pkg-config to fix provides
* Mon Feb 22 2010 meissner@suse.de
- disable FORTIFY_SOURCE, as HashMgr::add_word() and struct hentry
  with "char word;" at the end is not going to work out.
- run "make check" to spot such problems earlier
- added missing format arguments
* Thu Dec 17 2009 jengelh@medozas.de
- add baselibs.conf as a source
* Fri Jul 31 2009 mseben@suse.cz
- update to version 1.2.8
  * replist.*, hunspell.cxx, affixmgr.cxx: new input and output
  conversion support
  * tools/wordforms: word generation script for dictionary developers
  * hunspell/hunspell.cxx: extended BREAK feature: ^ and $ mean in break
  patterns the beginning and end of the word.
  * hunspell/hunspell.cxx: set default break at hyphen characters.
  * affixmgr.cxx: SIMPLIFIEDTRIPLE is a new affix file keyword to allow
  simplified forms of the compound words with triple repeating letters.
  * affixmgr.cxx: extend CHECKCOMPOUNDPATTERN to support alternations
  of compound words for example by sandhi feature of Indian and other
  languages.
  * tools/hunspell.cxx: add empty lines as separators to the output of
  the stemming and morphological analysis.
  * affixmgr.cxx: fix condition checking algorithm.
  * affixmgr,cxx: fix COMPOUNDWORDMAX feature.
  * csutil.cxx: fix bad conditional code for Mozilla compilation.
  * hunspell/hunspell.cxx: add missing ngram suggestion for HUHINITCAP
  (capitalized mixed case) words.
  * w_char.hxx: use GCC conditions for GCC related code.
  * affixmgr.cxx: check morphological description in morphgen()
  * tools/affixcompress: extended help for -h (use LC_ALL=C sort
  for input word list)
  * hunspell/hunspell.cxx: remove deprecated word breaking codes.
* Fri Aug 15 2008 lmichnovic@suse.cz
- update to version 1.2.7
  * FULLSTRIP: new option for affix handling. With FULLSTRIP, affix
  rules can strip full words, not only one less characters.
  * COMPOUNDRULE works with all flag types. (COMPOUNDRULE is for
  pattern matching. For example, en_US dictionary of
  OpenOffice.org uses COMPOUNDRULE for ordinal number recognition:
  1st, 2nd, 11th, 12th, 22nd, 112th, 1000122nd etc.).
  * optimized suggestions:
  - modified 1-character distance suggestion algorithms: search
    a TRY character in all position instead of all TRY characters
    in a character position (it can give more readable suggestion
    order, also better suggestions in the first positions, when
    TRY characters are sorted by frequency.)
    For example, suggestions for "moze":
    ooze, doze, Roze, maze, more etc. (Hunspell 1.2.6),
    maze, more, mote, ooze, mole etc. (Hunspell 1.2.7).
  * extended compound word checking for better COMPOUNDRULE related
  suggestions, for example English ordinal numbers: 121323th ->
  121323rd (it needs also a th->rd REP definition).
  * bug fixes (see Changelog)
* Tue Jul 15 2008 lmichnovic@suse.cz
- update to version 1.2.6
  * affentry.cxx: fixes of the affix rule matching algorithm
  (affected only the sk_SK dictionary from all OO.o dictionaries)
  - fix dot pattern + accented letters matching (if not Unicode)
  - word-length conditions work again
  * tests/condition.*: extended test for the fix.
  * hashmgr.cxx: load multiword expressions: spaces may be parts
  of the dictionary words again (but spaces also work as
  morphological field separators: word word2 -> "word word2",
  word po:noun -> "word").
  * man/hunspell.4: updated manual
  * tools/hunspell.cxx: add iconv character conversion support to
  stemming and morphological analysis
* Wed Jul  9 2008 lmichnovic@suse.cz
- update to version 1.2.5
  * fix affix rule condition checking of en_GB dictionary, also
  morphological analysis by dictionaries with two-level suffixes
* Wed Jun 18 2008 lmichnovic@suse.cz
- update to version 1.2.4-2
  with fixed comparison of char* pointer with a string literal
* Tue Jun 17 2008 lmichnovic@suse.cz
- version update Hunspell 1.2.4
  * add free_list() for C, C++ interfaces to deallocate suggestion
  lists
  - Hunspell 1.2.3
  * extended XML interface to use morphological functions by
  standard spell checking interface, spell() and suggest().
  See hunspell.3 manual page.
  * default dash suggestions for compound words: newword-> new word and new-word
  * new manual pages: hunspell.3, hzip.1, hunzip.1.
  * bug fixes
- obsoletes all previous patches
* Fri May  9 2008 aj@suse.de
- Add baselibs.conf.
* Tue May  6 2008 coolo@suse.de
- fix build
* Wed Apr 23 2008 lmichnovic@suse.cz
- fixed libdir and includedir in pkg-config file [bnc#382638]
  (hunspell-pkgconfig_libdir.patch)
* Tue Apr 15 2008 schwab@suse.de
- Avoid libtool namespace clash.
* Sun Apr 13 2008 lmichnovic@suse.cz
- update to 1.2.2 final
  * extended dictionary (dic file) support to use multiple base and
  special dictionaries.
  * new and improved options of command line hunspell:
  - m: morphological analysis or flag debug mode (without affix
  rule data it signs the flag of the affix rules)
  - s: stemming mode
  - D: list available dictionaries and search path
  - d: support extra dictionaries by comma separated list.
  * forbidding in personal dictionary (with asterisk, / signs
  affixation)
  * new affix compression tool "affixcompress": compression tool
  for large (millions of words) dictionaries.
  * improved manual
* Tue Feb 19 2008 lmichnovic@suse.cz
- no need to require %%release
* Thu Feb  7 2008 lmichnovic@suse.cz
- initial version 1.2.2 beta
- fixed uninitilized variable (*uninitialised.patch)
- fixed using function address instead of value
  (*function_address.patch)
